/*		 ICP-PCI Kernel module free public release
 *
 *		       Copyright (C) 1996-99 GOM mbH.
 *	         Rebenring 33, 38106 Braunschweig, GERMANY
 *		            All rights reserved
 *
 * $Id: config.h,v 5.1 1999/05/04 12:37:27 matthias Exp $
 *
 */

#ifndef _CONFIG_H
#define _CONFIG_H

/* function to read out config files (libconfig.a) */
int read_config (const char*, union icp_dev_t*, int, int, int, char*);

#define	MAX_ENTRY_LENGTH	64	/* max size of camera name (arg 6) */

/* config file, structure to fill in (allocated)
   board, module, camera, camera name to fill in (allocated!) */

/* function to test config files for supported hardware */
int test_config (const char*,	/* filename */
		 int *,		/* number of boards */
		 int *,
		 /* array of module type per board */
		 /* e.g. module[board] = ICP_AMVS/ICP_AMNO */
		 int [ICP_BOARDS_MAX][ICP_CAMERAS_MAX]);
		 /* array of supported cameras per board */
		 /* e.g. camera[board][camera]=TRUE/FALSE */ 

/* return values for read_config */
enum cnf_err_t {
  ECNF_ERR,
  EICP_FILE,			/* config file not found */
  EICP_BOARD,			/* no config section for specified board */
  				/* or invalid board argument */
  EICP_MODULE,			/* no config section for specified module */
  				/* or invalid module argument */
  EICP_CAMERA,			/* no config section for specified camera */
 				/* or invalid camera argument */
  EICP_OVERFLOW,		/* structure overflow (debugging) */
  EICP_IDENTIFIER,		/* identifier (first word in line) not found */
  EICP_ENUM_PARAMETER,		/* parameter (word after '=') invalid */
  EICP_NUM_PARAMETER,		/* parameter (digit after '=' invalid (unused) */
  EICP_NOT_SPECIFIED		/* self explaining */
};

#ifdef __CONFIG__
/* general type definition */

struct icp_cnf_flag_t {
  
  char		identifier[32];
  u_char	value;
};

struct icp_cnf_flag_debug_t {
  
  char		reg_name[32];
  char		meaning[64];
};

struct icp_cnf_enum_t {
  
  char		identifier[32];
  char		parameter[32];
  u_char	value;
};

struct icp_cnf_enum_debug_t {
  
  char		reg_name[32];
  char		meaning[64];
};

struct icp_cnf_num_t {
  
  char		identifier[32];
};

struct icp_cnf_num_debug_t {
  
  char		reg_name[32];
  char		meaning[64];
};

const struct icp_cnf_flag_t vs_cnf_flag[] = {

  "XTAL_Mode",				VS_CLKSRC_XTAL,
  "PLL_Mode",				VS_CLKSRC_PLL,
  "Interlaced",				VS_ILACE,
  "NonInterlaced",			VS_NON_ILACE,
  "LEN_Invert",				VS_LEN_LO,
  "LEN_NoInvert",			VS_LEN_HI,
  "FLD_Invert",				VS_FLD_INV,
  "FLD_NoInvert",			VS_FLD_NO_INV,
  "FEN_Invert",				VS_FEN_LO,
  "FEN_NoInvert",			VS_FEN_HI,
  "PCLK_Invert",			VS_PCLK_FA,
  "PCLK_NoInvert",			VS_PCLK_RI,
  "External_Pixel_Clock_Enable", 	VS_ENABLE,
  "External_Pixel_Clock_Disable",	VS_DISABLE,
  "Field_Sync_Enable",			VS_ENABLE,
  "Field_Sync_Disable",			VS_DISABLE,
  "Vertical_Sync_Enable",		VS_ENABLE,
  "Vertical_Sync_Disable",		VS_DISABLE,
  "Trigger_Gen_Enable",			VS_ENABLE,
  "Trigger_Gen_Disable",		VS_DISABLE,
  "Clamping_Enable",			VS_ENABLE,
  "Clamping_Disable",			VS_DISABLE,
  "Strobe_Polarity_Low",		VS_STRB_LO,
  "Strobe_Polarity_High",		VS_STRB_HI,
  "\0",					0
};

#ifdef DEBUG_ICPCI
const struct icp_cnf_flag_debug_t vs_cnf_flag_debug[] = {

  "clksrc ",	"Internal crystal mode",
  "clksrc ",	"Phase-locked loop mode",
  "smode  ",	"Interlaced camera",
  "smode  ",	"Non-interlaced camera",
  "lenpol ",	"LEN input active low, invert",
  "lenpol ",	"LEN input active high, no-invert",
  "fldpol ",	"0=odd field, 1=even field, invert",
  "fldpol ",	"0=even field, 1=odd field, no-invert",
  "fenpol ",	"FEN input active low, invert",
  "fenpol ",	"FEN input active high, no-invert",
  "pclkpol",	"Sample on falling edge, invert",
  "pclkpol",	"Sample on rising edge, no-invert",
  "eclken ",	"half clock frequency to camera",
  "eclken ",	"full clock frequency to camera",
  "fldsten",	"FLD comes from sync stripper",
  "fldsten",	"FLD comes from timing source",
  "vsten  ",	"VBlank comes from sync stripper",
  "vsten  ",	"VBlank comes from timing source",
  "trgen  ",	"Enable trigger",
  "trgen  ",	"Diasable trigger",
  "cpen   ",	"Clamp enabled",
  "cpen   ",	"Clamp disabled",
  "strbpol",	"Strobe active low",
  "strbpol",	"Strobe active high"
};
#endif /* DEBUG_ICPCI */

const struct icp_cnf_flag_t dg_cnf_flag[] = {

  "CCLK_14.32MHz",		DG_F_14_32,
  "CCLK_16.26MHz",		DG_F_16_26,
  "CCLK_32.51MHz",		DG_F_32_51,
  "CCLK_25.18MHz",		DG_F_25_18_I,
  "CCLK_28.32MHz",		DG_F_28_32_I,
  "CCLK_24.00MHz",		DG_F_24_00,
  "CCLK_40.00MHz",		DG_F_40_00,
  "CCLK_36.00MHz",		DG_F_36_00,
  "CCLK_44.90MHz",		DG_F_44_90,
  "CCLK_50.00MHz",		DG_F_50_00,
  "CCLK_Div1",			DG_D_1,
  "CCLK_Div2",			DG_D_2,
  "CCLK_Div4",			DG_D_4,
  "CCLK_Div8",			DG_D_8,
  "CCLK_Div16",			DG_D_16,
  "CCLK_Div32",			DG_D_32,
  "CCLK_Div64",			DG_D_64,
  "CCLK_Div128",		DG_D_128,
  "Xillix_Mode_Enable",		DG_ENABLE,
  "Xillix_Mode_Disable",	DG_DISABLE,
  "PCLK_Invert",		DG_PCLK_FA,
  "PCLK_NoInvert",		DG_PCLK_RI,
  "LEN_Invert",			DG_LEN_FA,
  "LEN_NoInvert",		DG_LEN_RI,
  "FEN_Invert",			DG_FEN_FA,
  "FEN_NoInvert",		DG_FEN_RI,
  "FLD_Invert",			DG_FLD_LO,
  "FLD_NoInvert",		DG_FLD_HI,
  "Area_Scan",			DG_AREA_SCAN,
  "Line_Scan",			DG_LINE_SCAN,
  "Interlaced",			DG_ILACE,
  "NonInterlaced",		DG_NON_ILACE,
  "LEN_Small",			DG_LEN_SMALL,
  "LEN_Wide",			DG_LEN_WIDE,
  "LineMiss_Mode",		DG_COMPAT_ICP,
  "No_LineMiss_Mode",		DG_COMPAT_MFG,
  "FIFO_Reset_Mode",		DG_FIFO_RESET,
  "Normal_FIFO_Mode",		DG_FIFO_NORMAL,
  "EXSCLK_14.32_Div2",		DG_C_7_16_M,
  "EXSCLK_14.32_Div8",		DG_C_1_79_M,
  "EXSCLK_14.32_Div32",		DG_C_447_5_k,
  "EXSCLK_14.32_Div128",	DG_C_112_k,
  "EXSCLK_14.32_Div512",	DG_C_28_k,
  "EXSCLK_14.32_Div2048",	DG_C_7_k,
  "EXSync_Counter_Enable",	DG_ENABLE,
  "EXSync_Counter_Disable",	DG_DISABLE,
  "EXSYNC_Pulse_Active_High",	DG_EXS_HI,
  "EXSYNC_Pulse_Active_Low",	DG_EXS_LO,
  "PRI_Enable",			DG_ENABLE,
  "PRI_Disable",		DG_DISABLE,
  "PRI_Active_High",		DG_PRI_HI,
  "PRI_Active_Low",		DG_PRI_LO,
  "Pixel_Size_8",		DG_PSIZE_8,
  "Pixel_Size_10",		DG_PSIZE_10,
  "Pixel_Size_12",		DG_PSIZE_12,
  "Pixel_Size_16",		DG_PSIZE_16,
  "Interleaved_Pixels",		DG_ILEAVE,
  "NonInterleaved_Pixels",	DG_NON_ILEAVE,
  "Trigger_Gen_Enable",		DG_ENABLE,
  "Trigger_Gen_Disable",	DG_DISABLE,
  "\0",				0
};

#ifdef DEBUG_ICPCI
const struct icp_cnf_flag_debug_t dg_cnf_flag_debug[] = {

  "fsel   ",	"f = 14.32 MHz",
  "fsel   ",	"f = 16.26 MHz",
  "fsel   ",	"f = 32.51 MHz",
  "fsel   ",	"f = 25.18 MHz",
  "fsel   ",	"f = 28.32 MHz",
  "fsel   ",	"f = 24.00 MHz",
  "fsel   ",	"f = 40.00 MHz",
  "fsel   ",	"f = 36.00 MHz",
  "fsel   ",	"f = 44.90 MHz",
  "fsel   ",	"f = 50.00 MHz",
  "clkdiv ",	"f / 1",
  "clkdiv ",	"f / 2",
  "clkdiv ",	"f / 4",
  "clkdiv ",	"f / 8",
  "clkdiv ",	"f / 16",
  "clkdiv ",	"f / 32",
  "clkdiv ",	"f / 64",
  "clkdiv ",	"f / 128",
  "xillen ",	"Xillix mode enable",
  "xillen ",	"Xillix mode disable",
  "pclkpol",	"Sample on falling edge, invert",
  "pclkpol",	"Sample on rising edge, no-invert",
  "lenpol ",	"LEN input active low, invert",
  "lenpol ",	"LEN input active high, no-invert",
  "fenpol ",	"FEN input active low, invert",
  "fenpol ",	"FEN input active high, no-invert",
  "fldpol ",	"0=odd field, 1=even field, invert",
  "fldpol ",	"0=even field, 1=odd field, no-invert",
  "smode  ",	"Area scan mode",
  "smode  ",	"Line scan mode",
  "ilmode ",	"Interlaced camera",
  "ilmode ",	"Non-interlaced camera",
  "lensm  ",	"LEN is smaller then PCLK",
  "lensm  ",	"LEN is grater then PCLK",
  "nolmiss",	"Two lines inserted (ICP)",
  "nolmiss",	"No lines inserted (MFG)",
  "lvar   ",	"Reset FIFO every FEN",
  "lvar   ",	"Normal FIFO operation",
  "exclk  ",	"t = 140ns (7.16 MHz)",
  "exclk  ",	"t = 558.6ns (1.79 MHz)",
  "exclk  ",	"t = 2.23us (447.5 kHz)",
  "exclk  ",	"t = 8.93us (112 kHz)",
  "exclk  ",	"t = 35.7us (28 kHz)",
  "exclk  ",	"t = 142us (7 kHz)",
  "exsen  ",	"External sync counter enabled",
  "exsen  ",	"External sync counter disabled",
  "exspol ",	"EXSYNC goes high when triggered",
  "exspol ",	"EXSYNC goes low when triggered",
  "prien  ",	"Programmable integration enabled",
  "prien  ",	"Programmable integaration disabled",
  "prip   ",	"PRIP output asserted low (always or inactive)",
  "prip   ",	"PRIP output asserted high (always or inactive)",
  "psize  ",	"Input pixel size 8 bit (256 LUT pages)",
  "psize  ",	"Input pixel size 10 bit (64 LUT pages)",
  "psize  ",	"Input pixel size 12 bit (16 LUT pages)",
  "psize  ",	"Input pixel size 16 bit (1 LUT page)",
  "ilpixel",	"Interleaved pixel mode",
  "ilpixel",	"Non-interleaved pixel mode",
  "trigen ",	"Trigger enabled",
  "trigen ",	"Trigger disabled"
};
#endif /* DEBUG_ICPCI */

const struct icp_cnf_flag_t pv_cnf_flag[] = {

  "HSync_Pol_Lo",			PV_HS_ACT_LOW,
  "HSync_Pol_Hi",			PV_HS_ACT_HIGH,
  "VSync_Pol_Lo",			PV_VS_ACT_LOW,
  "VSync_Pol_Hi",			PV_HS_ACT_HIGH,
  "LEN_Polarity_Hi",			PV_LP_ACT_HIGH,	      /* REV-B Only! */
  "LEN_Polarity_Lo",			PV_LP_ACT_LOW,	      /* REV-B Only! */
  "FEN_Polarity_Hi",			PV_FP_ACT_HIGH,	      /* REV-B Only! */
  "FEN_Polarity_Lo",			PV_FP_ACT_LOW,	      /* REV-B Only! */
  "FRST_Vsync_Disable",			PV_DISABLE,
  "FRST_Vsync_Enable",			PV_ENABLE,
  "FRST_Disable",			PV_DISABLE,
  "FRST_Enable",			PV_ENABLE,
  "FRST_Active_Hi",			PV_FR_ACT_HIGH,
  "FRST_Active_Lo",			PV_FR_ACT_LOW,
  "FRST_FROFF_Period",			PV_FRST_FROFF,
  "FRST_One_Line",			PV_FRST_LINE,
  "PTG_HSYNC_Select",			PV_HSYNC_OUT,
  "PTG_CSYNC_Select",			PV_CSYNC_OUT,
  "CHSYNCEN_Enable",			PV_CHSYNC_EN,
  "CHSYNCEN_Disable",			PV_CHSYNC_DIS,
  "VSYNCEN_Enable",			PV_VSYNC_EN,
  "VSYNCEN_Disable",			PV_VSYNC_DIS,
  "PLL_Mode",				PV_CLKSRC_PLL,
  "XTAL_Mode",				PV_CLKSRC_XTAL,
  "LPF_Disable",			PV_LPF_BYPASS,
  "LPF_Enable",				PV_LPF_6_0,
  "VSCAN_Disable",			PV_DISABLE,	      /* REV-B Only! */
  "VSCAN_Enable",			PV_ENABLE,	      /* REV-B Only! */
  "Scale_1",				PV_SCALE_1_0,
  "Scale_1.5",				PV_SCALE_1_5,
  "VClk_Normal",			PV_CP_ACT_HIGH,	      /* REV-B Only! */
  "VClk_Inverted",			PV_CP_ACT_LOW,	      /* REV-B Only! */
  "NonInterlaced",			PV_NON_ILACE,
  "Interlaced",				PV_ILACE,
  "FLDSHFT_Disable",			PV_DISABLE,
  "FLDSHFT_Enable",			PV_ENABLE,
  "Trig_Disable",			PV_DISABLE,
  "Trig_Enable",			PV_ENABLE,
  "Ext_Trigger",			PV_TRIG_EXT,
  "SW_Trigger",				PV_TRIG_SOFT,
  "Trigger_Active_Lo",			PV_TP_ACT_LOW,
  "Trigger_Active_Hi",			PV_TP_ACT_HIGH,
  "Strobe_Slow",			PV_STRBMD_SLOW,
  "Strobe_Fast",			PV_STRBMD_FAST,
  "Strobe_Disable",			PV_DISABLE,	      /* REV-B Only! */
  "Strobe_Enable",			PV_ENABLE,	      /* REV-B Only! */
  "Strobe_Active_Hi",			PV_SP_ACT_HIGH,
  "Strobe_Active_Lo",			PV_SP_ACT_LOW,
  "Skip_Field_Disable",			PV_DISABLE,
  "Skip_Field_Enable",			PV_ENABLE,
  "Clamp_On_LEN_Fall",			PV_CLMP_INVERT,
  "Clamp_On_LEN_Rise",			PV_CLMP_NO_INV,
  "Clamp_Src_Sync_Strip",		PV_CLMP_STRIP,
  "Clamp_Src_Prog",			PV_CLMP_PROG,
  "\0",					0
};

#ifdef DEBUG_ICPCI
const struct icp_cnf_flag_debug_t pv_cnf_flag_debug[] = {
  /* FIXME */
};
#endif /* DEBUG_ICPCI */

const struct icp_cnf_enum_t vs_cnf_enum[] = {

  "Timing_Option",		"RS170_10.00",		VS_T_0_10_00_RS170,
  "Timing_Option",		"MC1000P_20.00",	VS_T_1_20_00_MC1000P,
  "Timing_Option",		"RS170_12.28",		VS_T_0_12_28_RS170,
  "Timing_Option",		"RS170_14.32",		VS_T_0_14_32_RS170,
  "Timing_Option",		"CCIR_10.00",		VS_T_0_10_00_CCIR,
  "Timing_Option",		"CCIR_15.00",		VS_T_0_15_00_CCIR,
  "Timing_Option",		"CCIR_14.18",		VS_T_0_14_18_CCIR,
  "Timing_Option",		"Alternate_0",		VS_T_0_10_00_RS170,
  "Timing_Option",		"Alternate_1",		VS_T_1_20_00_MC1000P,
  "Timing_Option",		"Alternate_2",		VS_T_0_12_28_RS170,
  "Timing_Option",		"Alternate_3",		VS_T_0_14_32_RS170,
  "Timing_Option",		"Alternate_4",		VS_T_0_10_00_CCIR,
  "Timing_Option",		"Alternate_6",		VS_T_0_15_00_CCIR,
  "Timing_Option",		"Alternate_7",		VS_T_0_14_18_CCIR,
  "Filter_Type",		"LPF_3.0",		VS_LPF_3_0,
  "Filter_Type",		"LPF_4.3",		VS_LPF_4_3,
  "Filter_Type",		"LPF_6.5",		VS_LPF_6_5,
  "Filter_Type",		"LPF_12.0",		VS_LPF_12_0,
  "Video_Prescale",		"Scale_1.0",		VS_SCALE_1_0,
  "Video_Prescale",		"Scale_1.5",		VS_SCALE_1_5,
  "Video_Prescale",		"Scale_0.5",		VS_SCALE_0_5,
  "Video_Prescale",		"Scale_0.75",		VS_SCALE_0_75,
  "Window_Timing_Source",	"Standard_Timing_Generator",	VS_TSRC_STD,
  "Window_Timing_Source",	"External_Timing_Port_0",	VS_TSRC_EXT0,
  "Window_Timing_Source",	"External_Timing_Port_1",	VS_TSRC_EXT1,
  "Window_Timing_Source",	"External_Timing_Port_0_1",	VS_TSRC_DIF,
  "Trigger_Source",		"External",		VS_TRIG_EXT,
  "Trigger_Source",		"Software",		VS_TRIG_SOFT,
  "Frame_Reset_Mode",		"Low_Line",		VS_FMODE_LOW_LINE,
  "Frame_Reset_Mode",		"Low_VB",		VS_FMODE_LOW_VB,
  "Trigger_Mode",	"Trigger_On_Slow_Strobe",	VS_TMODE_SLOW_STROBE,
  "Trigger_Mode",		"Frame_Reset",		VS_TMODE_FRAME_RESET,
  "Trigger_Mode",		"Line_Scan",		VS_TMODE_LINE_SCAN,
  "Trigger_Mode",	"Trigger_On_Frame_Fast_Strobe",	VS_TMODE_FAST_STROBE,
  "Clamping_Source",		"Program_Clamp",	VS_CPSRC_PROG,
  "Clamping_Source",		"Auto_Clamp",		VS_CPSRC_AUTO,
  "Strobe_Source",		"Strobe_2",		VS_STRB_2,
  "Strobe_Source",		"Strobe_1",		VS_STRB_1,
  "\0",				"\0",			0
};

#ifdef DEBUG_ICPCI
const struct icp_cnf_enum_debug_t vs_cnf_enum_debug[] = {

  "tsel   ",	"f = 10 MHz (RS170)",
  "tsel   ",	"f = 20 MHz (MC1000P)",
  "tsel   ",	"f = 12.28 MHz (RS170)",
  "tsel   ",	"f = 14.32 MHz (RS170)",
  "tsel   ",	"f = 10.00 MHz (CCIR)",
  "tsel   ",	"f = 15.00 MHz (CCIR)",
  "tsel   ",	"f = 14.18 MHz (CCIR)",
  "tsel   ",	"f = 10 MHz (RS170)",
  "tsel   ",	"f = 20 MHz (MC1000P)",
  "tsel   ",	"f = 12.28 MHz (RS170)",
  "tsel   ",	"f = 14.32 MHz (RS170)",
  "tsel   ",	"f = 10.00 MHz (CCIR)",
  "tsel   ",	"f = 15.00 MHz (CCIR)",
  "tsel   ",	"f = 14.18 MHz (CCIR)",
  "lpfsel ",	"3.0 MHz -3dB bandwidth",
  "lpfsel ",	"4.3 MHz -3dB bandwidth",
  "lpfsel ",	"6.5 MHz -3dB bandwidth",
  "lpfsel ",	"12.0 MHz -3dB bandwidth",
  "iscale ",	"Scale video by 1.0",
  "iscale ",	"Scale video by 1.5",
  "iscale ",	"Scale video by 0.5",
  "iscale ",	"Scale video by 0.75",
  "tsrc   ",	"Standard timing generator",
  "tsrc   ",	"External timing 0",
  "tsrc   ",	"Extern timing 1",
  "tsrc   ",	"External differential timing",
  "trgsrc ",	"Enable external trigger",
  "trgsrc ",	"Enable software trigger",
  "fmode  ",	"Frame reset low one line",
  "fmode  ",	"Frame Reset low one v-blank",
  "tmode  ",	"Trigger on frame - slow strobe",
  "tmode  ",	"Frame reset",
  "tmode  ",	"Line scan",
  "tmode  ",	"Trigger on frame - fast strobe",
  "cpsrc  ",	"Programmable clamp pulse enabled",
  "cpsrc  ",	"Automatic clamp pulse enabled",
  "strbsel",	"Strobe 2 output enabled",
  "strbsel",	"Strobe 1 output enabled"
};
#endif /* DEBUG_ICPCI */

const struct icp_cnf_enum_t dg_cnf_enum[] = {

  "ExtSync_Mode",		"Disabled",		DG_FREE_RUN,
  "ExtSync_Mode",		"FreeRun",		DG_FREE_RUN,
  "ExtSync_Mode",		"Ext_Trigger",		DG_EXT_TRIG,
  "ExtSync_Mode",		"SW_Trigger",		DG_SOFT_TRIG,
  "ExtSync_Mode",		"FEN_Trigger",		DG_VB_TRIG,
  "AM_OutputA",			"High_Byte",		DG_MUXA_HI,
  "AM_OutputA",			"Low_Byte",		DG_MUXA_LO,
  "AM_OutputB",			"High_Byte",		DG_MUXB_HI,
  "AM_OutputB",			"Low_Byte",		DG_MUXB_LO,
  "AM_OutputC",			"High_Byte",		DG_MUXC_HI,
  "AM_OutputC",			"Low_Byte",		DG_MUXC_LO,
  "Trigger_Source",		"Software",		DG_TRIG_SOFT,
  "Trigger_Source",		"External",		DG_TRIG_EXT,
  "\0",				"\0",			0
};

#ifdef DEBUG_ICPCI
const struct icp_cnf_enum_debug_t dg_cnf_enum_debug[] = {

  "extmd  ",	"EXSYNC triggers itself",
  "extmd  ",	"EXSYNC triggers itself",
  "extmd  ",	"EXSYNC counter starts with external trigger",
  "extmd  ",	"EXSYNC counter starts with software trigger",
  "extmd  ",	"EXSYNC counter starts with v-blank",
  "muxa   ",	"High byte of input LUT to AMOutA",
  "muxa   ",	"Low byte of input LUT to AMOutA",
  "muxb   ",	"High byte of input LUT to AMOutB",
  "muxb   ",	"Low byte of input LUT to AMOutB",
  "muxc   ",	"High byte of input LUT to AMOutC",
  "muxc   ",	"Low byte of input LUT to AMOutC",
  "trigsrc",	"Trigger from camera connector",
  "trigsrc",	"Trigger from software"
};
#endif /* DEBUG_ICPCI */

/* PCVision config-file contains no enums */
const struct icp_cnf_enum_t pv_cnf_enum[] = {

  "\0",	"\0", 0
};

#ifdef DEBUG_ICPCI
const struct icp_cnf_enum_debug_t pv_cnf_enum_debug[] = {

};
#endif /* DEBUG_ICPCI */


const struct icp_cnf_num_t vs_cnf_num[] = {

  "Strobe_Delay",
  "Horizontal_Offset",
  "Horizontal_Active",
  "Vertical_Offset",
  "Vertical_Active",
  "FRESET_Duration",
  "Clamping_Offset",
  "Video_N_Ref",
  "Video_P_Ref",
  "\0"
};

#ifdef DEBUG_ICPCI
const struct icp_cnf_num_debug_t vs_cnf_num_debug[] = {

  "strbdly",	"Strobe Delay",
  "hoff   ",	"Horizontal Offset",
  "hsz    ",	"Horizontal Size",
  "voff   ",	"Vertical Offset",
  "vsz    ",	"Vertical Size",
  "froff  ",	"Frame Reset Offset",
  "cppos  ",	"Clamp Position",
  "nref   ",	"Negative Reference Voltage",
  "pref   ",	"Positive Reference Voltage"
};
#endif /* DEBUG_ICPCI */

const struct icp_cnf_num_t dg_cnf_num[] = {

  "Camera_Mode",
  "EXSCLK_CounterPreset",
  "Horizontal_Offset",
  "Horizontal_Active",
  "Vertical_Offset",
  "Vertical_Active",
  "\0"
};

#ifdef DEBUG_ICPCI
const struct icp_cnf_num_debug_t dg_cnf_num_debug[] = {

  "mc     ",	"Camera Mode",
  "extime ",	"External Sync Time",
  "hoff   ",	"Horizontal Offset",
  "hact   ",	"Horizontal Active",
  "voff   ",	"Vertical Offset",
  "vact   ",	"Vertical Active",
};
#endif /* DEBUG_ICPCI */

const struct icp_cnf_num_t pv_cnf_num[] = {

  "HTotal",
  "HSync_Low",
  "HEqual_End",
  "Serration_Total",
  "VTotal",
  "VSync_Low",
  "VGate_Start",
  "VGate_End",
  "HOffset",
  "HActive",
  "VOffset",
  "VActive",
  "Strobe_Delay",
  "FRST_Offset_Delay",
  "Clamp_Delay",
  "PRef",
  "NRef",
  "PLL_FDIV",
  "PLL_RDIV",
  "PLL_VCO",
  "PLL_PDA",
  "PLL_LCOUNT",
  "\0"
};

#ifdef DEBUG_ICPCI
const struct icp_cnf_num_debug_t pv_cnf_num_debug[] = {

  "HTotal",		"Horizontal Line Rate",
  "HSync_Low",		"Horizontal Sync Low End",
  "HEqual_End",		"Horizontal Equalization Pulse End",
  "Serration_Total",	"Serration Pulse End",
  "VTotal",		"Vertical Sync Total",
  "VSync_Low",		"Vertical Sync",
  "VGate_Start",	"Vertical Gate Start",
  "VGate_End",		"Vertical Gate End",
  "HOffset",		"Horizontal Offset",
  "HActive",		"Horizontal Active",
  "VOffset",		"Vertical Offset",
  "VActive",		"Vertical Active",
  "Strobe_Delay",	"Strobe Delay",
  "FRST_Offset_Delay",	"Frame Reset Delay",
  "Clamp_Delay",	"Clamp Delay Count",
  "PRef",		"Positive Reference",
  "NRef",		"Negative Reference"
  "PLL_FDIV",		"FeedBack Divider",
  "PLL_RDIV",		"Reference Divider",
  "PLL_VCO",		"VCO Gain",
  "PLL_PDA",		"Output Post Scaler",
  "PLL_LCOUNT",		"Load Counter",
};
#endif /* DEBUG_ICPCI */

#endif /* __CONFIG__ */

#endif /* _CONFIG_H */

